<?php

namespace NoccyLabs\TinyLog;

use Psr\Log\LogLevel;

class ConsoleSink implements LoggerSinkInterface
{
    public function log($level, $message, array $context=[])
    {
        // Make sure we have a stdout to write to
        if (empty(STDOUT)) {
            return;
        }
        
        if (posix_isatty(STDOUT)) {
            // assume we have ansi support
            list ($lvl_style, $msg_style) = $this->getColorsForLevel($level);
            $out_fmt = "{$lvl_style}[%s]\e[0m{$msg_style} %s\e[0m\n";
            $out_arg = [ $level, $message ];
        } else {
            // format as plain text
            $out_fmt = "[%s] %s\n";
            $out_arg = [ $level, $message ];
        }

        fprintf(STDOUT, $out_fmt, ...$out_arg);
    }

    private function getColorsForLevel($level)
    {
        switch ($level) {
            case LogLevel::DEBUG:
                return [ "\e[32m", "\e[32m" ];
            case LogLevel::INFO:
                return [ "\e[32;1m", "\e[92m" ];
            case LogLevel::NOTICE:
                return [ "\e[33m", "\e[33m" ];
            case LogLevel::WARNING:
                return [ "\e[33;1m", "\e[93m" ];
            case LogLevel::ERROR:
                return [ "\e[31m", "\e[31m" ];
            case LogLevel::CRITICAL:
                return [ "\e[31;1m", "\e[91;1m" ];
            case LogLevel::ALERT:
                return [ "\e[31;43m", "\e[31;43m" ];
            case LogLevel::EMERGENCY:
                return [ "\e[93;41m", "\e[93;41;1m" ];
            default:
                return [ null, null ];
        }
    }
}