<?php

namespace NoccyLabs\TinyLog;

use Psr\Log\LoggerInterface;
use Psr\Log\LoggerTrait;

class Logger implements LoggerInterface
{
    use LoggerTrait;

    protected $sinks = [];

    public function addSink($sink)
    {
        if (is_callable($sink) || ($sink instanceof LoggerSinkInterface)) {
            $this->sinks[] = $sink;
            return;
        }

        throw new \InvalidArgumentException("Logger sink should be callable or instance of LoggerSink");
    }

    public function log($level, $message, array $context=[])
    {
        if (count($this->sinks) == 0) {
            printf("[%s] %s\n", $level, $message);
            return;
        }
        foreach ($this->sinks as $sink) {
            if (is_callable($sink)) {
                $sink($level, $message, $context);
            } else {
                $sink->log($level, $message, $context);
            }
        }
    }
}